From d57306c7945becfba70d3139af0a3a8f525a6bb5 Mon Sep 17 00:00:00 2001
From: Junio C Hamano <junkio@cox.net>
Date: Sat, 20 Aug 2005 02:05:31 -0700
Subject: [PATCH] Create objects/info/ directory in init-db.

Signed-off-by: Junio C Hamano <junkio@cox.net>
---
 init-db.c        | 2 ++
 t/t0000-basic.sh | 7 ++++---
 2 files changed, 6 insertions(+), 3 deletions(-)

diff --git a/init-db.c b/init-db.c
index 1fb3f7fa79..50b16b34b0 100644
--- a/init-db.c
+++ b/init-db.c
@@ -249,5 +249,7 @@ int main(int argc, char **argv)
 	}
 	strcpy(path+len, "/pack");
 	safe_create_dir(path);
+	strcpy(path+len, "/info");
+	safe_create_dir(path);
 	return 0;
 }
diff --git a/t/t0000-basic.sh b/t/t0000-basic.sh
index 547488bd25..142b7bf388 100755
--- a/t/t0000-basic.sh
+++ b/t/t0000-basic.sh
@@ -28,11 +28,12 @@ test_expect_success \
     '.git/objects should be empty after git-init-db in an empty repo.' \
     'cmp -s /dev/null should-be-empty' 
 
 # also it should have 257 subdirectories.  258 is counting "objects"
 find .git/objects -type d -print >full-of-directories
 test_expect_success \
-    '.git/objects should have 257 subdirectories.' \
-    'test $(wc -l < full-of-directories) = 258'
+    '.git/objects should have 258 subdirectories.' \
+    'test $(wc -l < full-of-directories) = 259'
 
 ################################################################
 # Basics of the basics
@@ -28,11 +28,12 @@ test_expect_success \
     'cmp -s /dev/null should-be-empty' 
 
-# also it should have 257 subdirectories.  258 is counting "objects"
+# also it should have 258 subdirectories; 256 fan-out, pack, and info.
+# 259 is counting "objects" itself
 find .git/objects -type d -print >full-of-directories
 test_expect_success \